diff --git a/test_plans/checksum_offload_test_plan.rst b/test_plans/checksum_offload_test_plan.rst
index 6748aa34..db939b45 100644
--- a/test_plans/checksum_offload_test_plan.rst
+++ b/test_plans/checksum_offload_test_plan.rst
@@ -247,14 +247,14 @@ Start the packet forwarding::
 Send a packet with a good checksum::
 
    port=0, mbuf=0x2269df8780, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_GOOD  PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_GOOD  RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Send a packet with a bad checksum::
 
    port=0, mbuf=0x2269df7e40, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_BAD PKT_RX_IP_CKSUM_BAD PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_BAD RTE_MBUF_F_RX_IP_CKSUM_BAD RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Verify flags are as expected.
 
@@ -282,14 +282,14 @@ Start the packet forwarding::
 Send a packet with a good checksum::
 
    port=0, mbuf=0x2269df8780, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_GOOD  PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_GOOD  RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Send a packet with a bad checksum::
 
    port=0, mbuf=0x2269df7e40, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_BAD PKT_RX_IP_CKSUM_BAD PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_BAD RTE_MBUF_F_RX_IP_CKSUM_BAD RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Verify flags are as expected.
 
@@ -325,14 +325,14 @@ Start a packet capture on the tester in the background::
 Send a packet with a good checksum::
 
    port=0, mbuf=0x2269df8780, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_GOOD  PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_GOOD  RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Send a packet with a bad checksum::
 
    port=0, mbuf=0x2269df7e40, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_BAD PKT_RX_IP_CKSUM_GOOD PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_BAD RTE_MBUF_F_RX_IP_CKSUM_GOOD RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Inspect the pcap file from the packet capture and verify the checksums.
 
@@ -365,14 +365,14 @@ Start a packet capture on the tester in the background::
 Send a packet with a good checksum with a 1 in it's payload::
 
    port=0, mbuf=0x2269df8780, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_GOOD  PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_GOOD  RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Send a packet with a bad checksum with a 0 in it's payload::
 
    port=0, mbuf=0x2269df7e40, pkt_len=96, nb_segs=1:
-   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_BAD PKT_RX_OUTER_L4_CKSUM_UNKNOWN
-   tx: flags=PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+   rx: l2_len=18 ethertype=800 l3_len=20 l4_proto=17 l4_len=8 flags=RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_BAD RTE_MBUF_F_RX_OUTER_L4_CKSUM_UNKNOWN
+   tx: flags=RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 Inspect the pcap file from the packet capture and verify the checksums.
 
diff --git a/test_plans/ddp_gtp_qregion_test_plan.rst b/test_plans/ddp_gtp_qregion_test_plan.rst
index 84396852..596f4855 100644
--- a/test_plans/ddp_gtp_qregion_test_plan.rst
+++ b/test_plans/ddp_gtp_qregion_test_plan.rst
@@ -179,7 +179,7 @@ Test Case: Outer IPv6 dst controls GTP-C queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send outer dst GTP-C packet, check RSS could work, verify the queue is 
-   between 40 and 55, print PKT_RX_RSS_HASH::
+   between 40 and 55, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
     dst="2001:0db8:85a3:0000:0000:8a2e:0370:0001")/UDP(dport=2123)/
@@ -229,7 +229,7 @@ Test Case: TEID controls GTP-C queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send teid GTP-C packet, check RSS could work, verify the queue is 
-   between 40 and 55, print PKT_RX_RSS_HASH::
+   between 40 and 55, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6()/UDP(dport=2123)/GTP_U_Header(teid=0xfe)/Raw('x'*20) 
 
@@ -269,7 +269,7 @@ Test Case: TEID controls GTP-U IPv4 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send teid GTP-U IPv4 packet, check RSS could work, verify the queue is 
-   between 1 and 8, print PKT_RX_RSS_HASH::
+   between 1 and 8, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header(teid=0xfe)/IP()/Raw('x'*20)
 	
@@ -309,7 +309,7 @@ Test Case: Sport controls GTP-U IPv4 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send sport GTP-U IPv4 packet, check RSS could work, verify the queue is 
-   between 1 and 8, print PKT_RX_RSS_HASH::
+   between 1 and 8, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header(teid=30)/IP()/
     UDP(sport=100,dport=200)/Raw('x'*20)
@@ -351,7 +351,7 @@ Test Case: Dport controls GTP-U IPv4 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send dprot GTP-U IPv4 packet, check RSS could work, verify the queue is 
-   between 1 and 8, print PKT_RX_RSS_HASH::
+   between 1 and 8, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header(teid=30)/IP()/
     UDP(sport=100,dport=200)/Raw('x'*20)
@@ -393,7 +393,7 @@ Test Case: Inner IP src controls GTP-U IPv4 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner src GTP-U IPv4 packet, check RSS could work, verify the queue is 
-   between 1 and 8, print PKT_RX_RSS_HASH::
+   between 1 and 8, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP()/Raw('x'*20)
@@ -441,7 +441,7 @@ Test Case: Inner IP dst controls GTP-U IPv4 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner dst GTP-U IPv4 packet, check RSS could work, verify the queue is 
-   between 1 and 8, print PKT_RX_RSS_HASH::
+   between 1 and 8, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP()/Raw('x'*20)
@@ -488,7 +488,7 @@ Test Case: TEID controls GTP-U IPv6 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send teid GTP-U IPv6 packet, check RSS could work, verify the queue is 
-   between 10 and 25, print PKT_RX_RSS_HASH::
+   between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=0xfe)/IPv6()/
     UDP(sport=100,dport=200)/Raw('x'*20)
@@ -530,7 +530,7 @@ Test Case: Sport controls GTP-U IPv6 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send sport GTP-U IPv6 packet, check RSS could work, verify the queue is 
-   between 10 and 25, print PKT_RX_RSS_HASH::
+   between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/IPv6()/
     UDP(sport=100,dport=200)/Raw('x'*20)
@@ -572,7 +572,7 @@ Test Case: Dport controls GTP-U IPv6 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send dport GTP-U IPv6 packet, check RSS could work, verify the queue 
-   is between 10 and 25, print PKT_RX_RSS_HASH::
+   is between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/IPv6()/
     UDP(sport=100,dport=200)/Raw('x'*20)
@@ -621,7 +621,7 @@ Test Case: Inner IPv6 src controls GTP-U IPv6 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner src address GTP-U IPv6 packets, check RSS could work, verify 
-   the queue is between 10 and 25, print PKT_RX_RSS_HASH::
+   the queue is between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
@@ -677,7 +677,7 @@ Test Case: Inner IPv6 dst controls GTP-U IPv6 queue in queue region
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner dst GTP-U IPv6 packets, check RSS could work, verify the 
-   queue is between 10 and 25, print PKT_RX_RSS_HASH::
+   queue is between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
@@ -1141,7 +1141,7 @@ Test Case: Outer 64 bit prefix dst controls GTP-C queue
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send outer dst GTP-C packet, check RSS could work, verify the queue is
-   between 40 and 55, print PKT_RX_RSS_HASH::
+   between 40 and 55, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
     dst="2001:0db8:85a3:0000:0000:8a2e:0370:0001")/UDP(dport=2123)/
@@ -1201,7 +1201,7 @@ Test Case: Inner 48 bit prefix src controls GTP-U IPv6 queue
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner src address GTP-U IPv6 packets, check RSS could work, verify
-   the queue is between 10 and 25, print PKT_RX_RSS_HASH::
+   the queue is between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
@@ -1260,7 +1260,7 @@ Test Case: Inner 32 bit prefix dst controls GTP-U IPv6 queue
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner dst GTP-U IPv6 packets, check RSS could work, verify the
-   queue is between 10 and 25, print PKT_RX_RSS_HASH::
+   queue is between 10 and 25, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=30)/
     IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
diff --git a/test_plans/ddp_gtp_test_plan.rst b/test_plans/ddp_gtp_test_plan.rst
index cea2993f..77130270 100644
--- a/test_plans/ddp_gtp_test_plan.rst
+++ b/test_plans/ddp_gtp_test_plan.rst
@@ -139,7 +139,7 @@ Test Case: GTP-C FDIR packet for PF
     p=Ether()/IP()/UDP(dport=2123)/GTP_U_Header(teid=0x3456)/Raw('x'*20) 
 
 4. Check PF could receive configured TEID GTP-C packet, checksum is good,
-   queue is configured queue, ptypes are correct, check PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check RTE_MBUF_F_RX_FDIR print.
 
 5. Send GTP-C packet with bad checksum, dport is 2123, TEID is same
    as configured rule::
@@ -147,11 +147,11 @@ Test Case: GTP-C FDIR packet for PF
     p=Ether()/IP()/UDP(chksum=0x1234,dport=2123)/GTP_U_Header(teid=0x3456)/Raw('x'*20) 
    
 6. Check PF could receive configured TEID GTP packet, checksum is good, 
-   queue is configured queue, ptypes are correct, check PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check RTE_MBUF_F_RX_FDIR print.
    
 7. Send some TEIDs are not same as configured rule or other types packets, 
    check checksum are good, queue is 0, ptypes are correct, check no 
-   PKT_RX_FDIR print.
+   RTE_MBUF_F_RX_FDIR print.
   
 
 Test Case: GTP-C Cloud filter packet for PF
@@ -170,7 +170,7 @@ Test Case: GTP-C Cloud filter packet for PF
     p=Ether()/IP()/UDP(dport=2123)/GTP_U_Header(teid=0x12345678)/Raw('x'*20)
 
 4. Check PF could receive configured TEID GTP-C packet, checksum is good,
-   queue is configured queue, ptypes are correct, check no PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check no RTE_MBUF_F_RX_FDIR print.
 
 5. Send GTP-C packet with bad checksum, dport is 2123, TEID is same
    as configured rule::
@@ -178,11 +178,11 @@ Test Case: GTP-C Cloud filter packet for PF
     p=Ether()/IP()/UDP(chksum=0x1234,dport=2123)/GTP_U_Header(teid=0x12345678)/Raw('x'*20)
 
 6. Check PF could receive configured TEID GTP packet, checksum is good, 
-   queue is configured queue, ptypes are correct, check no PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check no RTE_MBUF_F_RX_FDIR print.
 
 7. Send some TEIDs are not same as configured rule or other types packets, 
    check checksum are good, queue is 0, ptypes are correct, no 
-   PKT_RX_FDIR print.
+   RTE_MBUF_F_RX_FDIR print.
 
 
 Test Case: GTP-U FDIR packet for PF
@@ -205,7 +205,7 @@ Test Case: GTP-U FDIR packet for PF
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=0x123456)/IPv6()/Raw('x'*20)
 
 4. Check PF could receive configured TEID GTP-U packet, checksum is good,
-   queue is configured queue, ptypes are correct, check PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check RTE_MBUF_F_RX_FDIR print.
    
 5. Send GTP-U packet with bad checksum, dport is 2152, TEID is same
    as configured rule::
@@ -215,11 +215,11 @@ Test Case: GTP-U FDIR packet for PF
     p=Ether()/IP()/UDP(chksum=0x1234,dport=2152)/GTP_U_Header(teid=0x123456)/IPv6()/Raw('x'*20)
 
 6. Check PF could receive configured TEID GTP packet, checksum is good, queue 
-   is configured queue, ptypes are corrcet, check PKT_RX_FDIR print.
+   is configured queue, ptypes are corrcet, check RTE_MBUF_F_RX_FDIR print.
    
 7. Send some TEIDs are not same as configured rule or other types packets, 
    check checksum are good, queue is 0, pytpes are correct, check no 
-   PKT_RX_FDIR print.
+   RTE_MBUF_F_RX_FDIR print.
 
 
 Test Case: GTP-U Cloud filter packet for PF
@@ -238,7 +238,7 @@ Test Case: GTP-U Cloud filter packet for PF
     p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header(teid=0x12345678)/Raw('x'*20)
    		
 4. Check PF could receive configured TEID GTP-U packet, checksum is good,
-   queue is configured queue, ptypes are correct, check no PKT_RX_FDIR print.
+   queue is configured queue, ptypes are correct, check no RTE_MBUF_F_RX_FDIR print.
 
 5. Send GTP-U packet with bad checksum, dport is 2152, TEID is same
    as configured rule::
@@ -246,11 +246,11 @@ Test Case: GTP-U Cloud filter packet for PF
     p=Ether()/IP()/UDP(chksum=0x1234,dport=2152)/GTP_U_Header(teid=0x12345678)/Raw('x'*20)
 
 6. Check PF could receive configured TEID GTP packet, checksum is good, queue
-   is configured queue, ptypes are correct, check no PKT_RX_FDIR print.
+   is configured queue, ptypes are correct, check no RTE_MBUF_F_RX_FDIR print.
 
 7. Send some TEIDs are not same as configured rule or other types packets, 
    check checksum are good, queue is 0, ptypes are correct, no 
-   PKT_RX_FDIR print.
+   RTE_MBUF_F_RX_FDIR print.
    
    
 Test Case: GTP-C Cloud filter packet for VF
diff --git a/test_plans/ddp_ppp_l2tp_test_plan.rst b/test_plans/ddp_ppp_l2tp_test_plan.rst
index 88a6da1b..8f51ff20 100644
--- a/test_plans/ddp_ppp_l2tp_test_plan.rst
+++ b/test_plans/ddp_ppp_l2tp_test_plan.rst
@@ -164,7 +164,7 @@ Test Case: RSS for PPPoE with default input set
 5. Start testpmd, set fwd rxonly, enable output print
 
 6. Default hash input set are MAC SA, session ID. Send sessionid
-   PPPoE PAY packet, check RSS could work, print PKT_RX_RSS_HASH::
+   PPPoE PAY packet, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether(src="3C:FD:FE:A3:A0:01", dst="4C:FD:FE:A3:A0:01")/
     PPPoE(sessionid=0x7)
@@ -208,7 +208,7 @@ Test Case: RSS for PPPoE Ipv4 with default input set
 5. Start testpmd, set fwd rxonly, enable output print
 
 6. Default hash input set are IPv4 SA, IPv4 DA, sport, dport. Send PPPoE
-   IPv4 packet, check RSS could work, print PKT_RX_RSS_HASH::
+   IPv4 packet, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/PPPoE(sessionid=0x7)/PPP(proto=0x21)/IP(src="1.1.1.1",
     dst="2.2.2.2")/UDP(sport=4000,dport=8000)/Raw('x' * 20)
@@ -251,7 +251,7 @@ Test Case: RSS for PPPoE IPv6 with default input set
 5. Start testpmd, set fwd rxonly, enable output print
 
 6. Default hash input set are IPv6 SA, IPv6 DA, sport, dport. Send PPPoE
-   IPv6 packet, check RSS could work, print PKT_RX_RSS_HASH::
+   IPv6 packet, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/PPPoE(sessionid=0x7)/PPP(proto=0x57)/
     IPv6(src="1001:0db8:85a3:0000:0000:8a2e:0370:0001",
@@ -306,7 +306,7 @@ Test Case: RSS for L2TPv2 PAY with default input set
 5. Start testpmd, set fwd rxonly, enable output print
 
 6. Default hash input set are MAC SA, session ID. Send sessionid
-   L2TP PAY packet, check RSS could work, print PKT_RX_RSS_HASH::
+   L2TP PAY packet, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether(src="3C:FD:FE:A3:A0:01", dst="4C:FD:FE:A3:A0:01")/IP()/
     UDP(dport=1701, sport=1701)/L2TP(sessionid=0x7)/Raw('x' * 20)
@@ -357,7 +357,7 @@ Test Case: RSS for PPPoE according to sessionid
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send sessionid PPPoE PAY packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether(src="3C:FD:FE:A3:A0:01", dst="4C:FD:FE:A3:A0:01")/
     PPPoE(sessionid=0x7)
@@ -398,7 +398,7 @@ Test Case: RSS for PPPoE according to source address
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send source address PPPoE PAY packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether(src="3C:FD:FE:A3:A0:01", dst="4C:FD:FE:A3:A0:01")/
     PPPoE(sessionid=0x7)
@@ -444,7 +444,7 @@ Test Case: RSS for PPPoL2TP IPv4 according to inner source IPv4
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner source IPv4 PPPoL2TP IPv4 packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=1701, sport=1701)/PPP_L2TP(proto=0x0021)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP(sport=4000, dport=8000)/Raw('x' * 20)
@@ -490,7 +490,7 @@ Test Case: RSS for PPPoL2TP IPv4 according to inner destination IPv4
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send inner destination IPv4 PPPoL2TP IPv4 packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=1701, sport=1701)/PPP_L2TP(proto=0x0021)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP(sport=4000, dport=8000)/Raw('x' * 20)
@@ -535,7 +535,7 @@ Test Case: RSS for PPPoL2TP IPv4 according to sport
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send sport PPPoL2TP IPv4 packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=1701, sport=1701)/PPP_L2TP(proto=0x0021)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP(sport=4000, dport=8000)/Raw('x' * 20)
@@ -580,7 +580,7 @@ Test Case: RSS for PPPoL2TP IPv4 according to dport
 7. Start testpmd, set fwd rxonly, enable output print
 
 8. Send dport PPPoL2TP IPv4 packet, check RSS could work, print
-   PKT_RX_RSS_HASH::
+   RTE_MBUF_F_RX_RSS_HASH::
 
     p=Ether()/IP()/UDP(dport=1701, sport=1701)/PPP_L2TP(proto=0x0021)/
     IP(src="1.1.1.1",dst="2.2.2.2")/UDP(sport=4000, dport=8000)/Raw('x' * 20)
diff --git a/test_plans/dynamic_flowtype_test_plan.rst b/test_plans/dynamic_flowtype_test_plan.rst
index ad68536c..1acf60c8 100644
--- a/test_plans/dynamic_flowtype_test_plan.rst
+++ b/test_plans/dynamic_flowtype_test_plan.rst
@@ -157,7 +157,7 @@ Test Case: Reset flow type to pctype mapping
 
 6. Start testpmd
 
-7. Send normal packet to port, check RSS could work, print PKT_RX_RSS_HASH::
+7. Send normal packet to port, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
     
     >>> p=Ether()/IP()/Raw('x'*20)
 
@@ -182,13 +182,13 @@ Test Case: Update flow type to GTP-U IPv4 pctype mapping item
 
 5. Start testpmd
 
-6. Send GTP-U IPv4 packets, check RSS could work, print PKT_RX_RSS_HASH::
+6. Send GTP-U IPv4 packets, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     >>> p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header()/IP()/Raw('x'*20)
     >>> p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header()/IP()/Raw('x'*20)
 
 7. Send GTP-U IPv6, GTP-U PAY4 and GTP-C PAY4 packets, check receive packets 
-   from queue 0 and don't have PKT_RX_RSS_HASH print.
+   from queue 0 and don't have RTE_MBUF_F_RX_RSS_HASH print.
   
 
 Test Case: Update flow type to GTP-U IPv6 pctype mapping item
@@ -211,13 +211,13 @@ Test Case: Update flow type to GTP-U IPv6 pctype mapping item
 
 5. Start testpmd
 
-6. Send GTP-U IPv6 packets, check RSS could work, print PKT_RX_RSS_HASH::
+6. Send GTP-U IPv6 packets, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     >>> p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header()/IPv6()/Raw('x'*20)
     >>> p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header()/IPv6()/Raw('x'*20)
 
 7. Send GTP-U IPv4, GTP-U PAY4 and GTP-C PAY4 packets, check receive 
-   packets from queue 0 and don't have PKT_RX_RSS_HASH print
+   packets from queue 0 and don't have RTE_MBUF_F_RX_RSS_HASH print
   
 
   
@@ -241,13 +241,13 @@ Test Case: Update flow type to GTP-U PAY4 pctype mapping item
 
 5. Start testpmd
 
-6. Send GTP-U, PAY4 packets, check RSS could work, print PKT_RX_RSS_HASH::
+6. Send GTP-U, PAY4 packets, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     >>> p=Ether()/IP()/UDP(dport=2152)/GTP_U_Header()/Raw('x'*20)
     >>> p=Ether()/IPv6()/UDP(dport=2152)/GTP_U_Header()/Raw('x'*20)
 
 7. Send GTP-U IPv4, GTP-U IPv6 and GTP-C PAY4 packets, check receive 
-   packets from queue 0 and don't have PKT_RX_RSS_HASH print.
+   packets from queue 0 and don't have RTE_MBUF_F_RX_RSS_HASH print.
  
 	  
 Test Case: Update flow type to GTP-C PAY4 pctype mapping item
@@ -268,13 +268,13 @@ Test Case: Update flow type to GTP-C PAY4 pctype mapping item
 
 5. Start testpmd
 
-6. Send GTP-C PAY4 packets, check RSS could work, print PKT_RX_RSS_HASH::
+6. Send GTP-C PAY4 packets, check RSS could work, print RTE_MBUF_F_RX_RSS_HASH::
 
     >>> p=Ether()/IP()/UDP(dport=2123)/GTP_U_Header()/Raw('x'*20)
     >>> p=Ether()/IPv6()/UDP(dport=2123)/GTP_U_Header()/Raw('x'*20)
 
 7. Send GTP-U IPv4, GTP-U IPv6 and GTP-U PAY4 packets, check receive packets
-   from queue 0 and don't have PKT_RX_RSS_HASH print.
+   from queue 0 and don't have RTE_MBUF_F_RX_RSS_HASH print.
 
    
 GTP packet
diff --git a/test_plans/rxtx_offload_test_plan.rst b/test_plans/rxtx_offload_test_plan.rst
index d008d433..29b23bcd 100644
--- a/test_plans/rxtx_offload_test_plan.rst
+++ b/test_plans/rxtx_offload_test_plan.rst
@@ -212,10 +212,10 @@ Test case: Rx offload per-port setting in command-line
 
 2) Check the rx flags::
 
-    PKT_RX_L4_CKSUM_GOOD PKT_RX_IP_CKSUM_GOOD
-    PKT_RX_L4_CKSUM_BAD PKT_RX_IP_CKSUM_BAD
-    PKT_RX_L4_CKSUM_BAD PKT_RX_IP_CKSUM_GOOD
-    PKT_RX_L4_CKSUM_UNKNOWN PKT_RX_IP_CKSUM_BAD
+    RTE_MBUF_F_RX_L4_CKSUM_GOOD RTE_MBUF_F_RX_IP_CKSUM_GOOD
+    RTE_MBUF_F_RX_L4_CKSUM_BAD RTE_MBUF_F_RX_IP_CKSUM_BAD
+    RTE_MBUF_F_RX_L4_CKSUM_BAD RTE_MBUF_F_RX_IP_CKSUM_GOOD
+    RTE_MBUF_F_RX_L4_CKSUM_UNKNOWN RTE_MBUF_F_RX_IP_CKSUM_BAD
 
 2. Disable the rx cksum per_port::
 
@@ -292,7 +292,7 @@ Test case: NNT Rx offload per-queue setting
     pkt2 = Ether(dst="00:00:00:00:01:00", src="00:02:00:00:00:01")/Dot1Q(vlan=1)/IP(src="192.168.0.2", dst="192.168.0.3")/UDP(sport=33,dport=34)/Raw('x'*20)
 
    Port0 receive the two packets in queue2 and queue3.
-   Queue2 should capture strip vlan information like "VLAN tci=0x1" and "PKT_RX_VLAN_STRIPPED",
+   Queue2 should capture strip vlan information like "VLAN tci=0x1" and "RTE_MBUF_F_RX_VLAN_STRIPPED",
    queue3 doesn't support vlan strip.
 
    If set "set fwd mac",
@@ -315,7 +315,7 @@ Test case: NNT Rx offload per-queue setting
       Queue[ 3] : VLAN_STRIP
 
    Send the same packets,
-   Queue3 should capture strip vlan information like "VLAN tci=0x1" and "PKT_RX_VLAN_STRIPPED",
+   Queue3 should capture strip vlan information like "VLAN tci=0x1" and "RTE_MBUF_F_RX_VLAN_STRIPPED",
    queue2 doesn't support vlan strip.
 
 6. Enable vlan_strip per_port::
@@ -542,7 +542,7 @@ Test case: Tx offload checksum
 
 2) Check the tx flags::
 
-    PKT_TX_L4_NO_CKSUM PKT_TX_IPV4
+    RTE_MBUF_F_TX_L4_NO_CKSUM RTE_MBUF_F_TX_IPV4
 
 2. Enable the tx ipv4_cksum of port 1::
 
@@ -564,23 +564,23 @@ Test case: Tx offload checksum
 
     sendp([Ether(dst="00:00:00:00:01:00")/IP(src="100.0.0.1", dst="100.0.0.2")/UDP(sport=1024,dport=1025)], iface="enp131s0f3")
 
-   There is printing "PKT_TX_IP_CKSUM" and "PKT_TX_L4_NO_CKSUM" in the tx line.
+   There is printing "RTE_MBUF_F_TX_IP_CKSUM" and "RTE_MBUF_F_TX_L4_NO_CKSUM" in the tx line.
 
 4. Disable tx ipv4_cksum and enable tx udp_cksum,
-   then send the same ipv4-udp packet, there is printing "PKT_TX_UDP_CKSUM",
-   but no "PKT_TX_IP_CKSUM".
+   then send the same ipv4-udp packet, there is printing "RTE_MBUF_F_TX_UDP_CKSUM",
+   but no "RTE_MBUF_F_TX_IP_CKSUM".
 
 5. Try step 4 with "tcp_cksum" on, then send an ipv4-tcp packet::
 
     sendp([Ether(dst="00:00:00:00:01:00")/IP(src="100.0.0.1", dst="100.0.0.2")/TCP(sport=1024,dport=1025)], iface="enp131s0f3")
 
-   There is printing "PKT_TX_TCP_CKSUM".
+   There is printing "RTE_MBUF_F_TX_TCP_CKSUM".
 
 6. Try step 4 with "sctp_cksum" on, then send an ipv4-sctp packet::
 
     sendp([Ether(dst="00:00:00:00:01:00")/IP(src="100.0.0.1", dst="100.0.0.2")/sctp(sport=1024,dport=1025)], iface="enp131s0f3")
 
-   There is printing "PKT_TX_SCTP_CKSUM".
+   There is printing "RTE_MBUF_F_TX_SCTP_CKSUM".
 
 Test case: Tx offload per-queue and per-port setting
 ====================================================
diff --git a/tests/TestSuite_ddp_gtp.py b/tests/TestSuite_ddp_gtp.py
index c992e049..7bee4647 100644
--- a/tests/TestSuite_ddp_gtp.py
+++ b/tests/TestSuite_ddp_gtp.py
@@ -379,7 +379,7 @@ class TestDdpGtp(TestCase):
                                 layer_type in out,
                                 "Failed to output ptype information!!!")
                     if queue != 0 and type is 'fdir':
-                        self.verify(count == out.count("PKT_RX_FDIR"),
+                        self.verify(count == out.count("RTE_MBUF_F_RX_FDIR"),
                                     "Failed to test flow director!!!")
                     count = 0
                     if teid == wrong_teid or match_opt == 'not matched':
diff --git a/tests/TestSuite_ddp_gtp_qregion.py b/tests/TestSuite_ddp_gtp_qregion.py
index e7e40cfc..54ec3a7c 100644
--- a/tests/TestSuite_ddp_gtp_qregion.py
+++ b/tests/TestSuite_ddp_gtp_qregion.py
@@ -238,7 +238,7 @@ class TestDdpGtpQregion(TestCase):
                 pkt = packet.Packet(pkts[packet_type])
                 pkt.send_pkt(crb=self.tester, tx_port=self.tester_intf)
                 out = self.dut.get_session_output(timeout=2)
-                self.verify("PKT_RX_RSS_HASH" in out, "Failed to test RSS!!!")
+                self.verify("RTE_MBUF_F_RX_RSS_HASH" in out, "Failed to test RSS!!!")
                 pattern = "port (\d)/queue (\d{1,2}): received (\d) packets"
                 qnum = self.element_strip(out, pattern)
                 if opt is 'word_opt':
diff --git a/tests/TestSuite_ddp_mpls.py b/tests/TestSuite_ddp_mpls.py
index 7c677c3c..60f450c0 100644
--- a/tests/TestSuite_ddp_mpls.py
+++ b/tests/TestSuite_ddp_mpls.py
@@ -214,7 +214,7 @@ class Testddp_mpls(TestCase):
 
                 self.verify("port 0/queue %d" % queue in out,
                     "Failed to receive packet in this queue!!!")
-                self.verify("PKT_RX_L4_CKSUM_GOOD" in out,"Failed to check CKSUM!!!")
+                self.verify("RTE_MBUF_F_RX_L4_CKSUM_GOOD" in out,"Failed to check CKSUM!!!")
             label = wrong_label
             queue = 0
 
diff --git a/tests/TestSuite_ddp_ppp_l2tp.py b/tests/TestSuite_ddp_ppp_l2tp.py
index 57b8c352..368f282b 100644
--- a/tests/TestSuite_ddp_ppp_l2tp.py
+++ b/tests/TestSuite_ddp_ppp_l2tp.py
@@ -183,7 +183,7 @@ class TestDdpPppL2tp(TestCase):
             out = self.dut.get_session_output(timeout=2)
             print(out)
             if type is 'rss':
-                self.verify("PKT_RX_RSS_HASH" in out, "Failed to test RSS!!!")
+                self.verify("RTE_MBUF_F_RX_RSS_HASH" in out, "Failed to test RSS!!!")
             pattern = "port (\d)/queue (\d{1,2}): received (\d) packets"
             qnum = self.element_strip(out, pattern)
             ptypes = packet_type.split('/')
diff --git a/tests/TestSuite_dynamic_flowtype.py b/tests/TestSuite_dynamic_flowtype.py
index d60a5822..9e6f2710 100644
--- a/tests/TestSuite_dynamic_flowtype.py
+++ b/tests/TestSuite_dynamic_flowtype.py
@@ -207,12 +207,12 @@ class TestDynamicFlowtype(TestCase):
             pkt.send_pkt(crb=self.tester, tx_port=self.tester_intf)
             out = self.dut.get_session_output(timeout=2)
             if match_opt == 'matched':
-                self.verify("PKT_RX_RSS_HASH" in out,
+                self.verify("RTE_MBUF_F_RX_RSS_HASH" in out,
                             "Failed to receive packet in rss queue!!!")
             elif match_opt == 'not matched':
                 self.verify("port 0/queue 0" in out,
                             "Failed to receive packet in queue 0!!!")
-                self.verify("PKT_RX_RSS_HASH" not in out,
+                self.verify("RTE_MBUF_F_RX_RSS_HASH" not in out,
                             "Failed to receive packet in queue 0!!!")
 
     def dynamic_flowtype_test(self, pctype=22, flowtype=26, reset=False):
diff --git a/tests/TestSuite_ipgre.py b/tests/TestSuite_ipgre.py
index 5e7750c5..5180abeb 100644
--- a/tests/TestSuite_ipgre.py
+++ b/tests/TestSuite_ipgre.py
@@ -247,21 +247,21 @@ class TestIpgre(TestCase):
                 "MAC_IPv6_GRE_IPv4-TUNNEL_UDP_PKT":           ["TUNNEL_GRENAT", "INNER_L4_UDP"],
                 "MAC_IPv6_GRE_IPv4-TUNNEL_TCP_PKT":           ["TUNNEL_GRENAT", "INNER_L4_TCP"],
                 "MAC_IPv6_GRE_IPv4-TUNNEL_SCTP_PKT":          ["TUNNEL_GRENAT", "INNER_L4_SCTP"],
-                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_UDP_PKT":      ["TUNNEL_GRENAT", "INNER_L4_UDP", "PKT_RX_VLAN"],
-                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_TCP_PKT":      ["TUNNEL_GRENAT", "INNER_L4_TCP", "PKT_RX_VLAN"],
-                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_SCTP_PKT":     ["TUNNEL_GRENAT", "INNER_L4_SCTP", "PKT_RX_VLAN"]
+                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_UDP_PKT":      ["TUNNEL_GRENAT", "INNER_L4_UDP", "RTE_MBUF_F_RX_VLAN"],
+                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_TCP_PKT":      ["TUNNEL_GRENAT", "INNER_L4_TCP", "RTE_MBUF_F_RX_VLAN"],
+                "MAC_VLAN_IPv6_GRE_IPv4-TUNNEL_SCTP_PKT":     ["TUNNEL_GRENAT", "INNER_L4_SCTP", "RTE_MBUF_F_RX_VLAN"]
             }
 
             pkt_types_ipv6_ipv6 = {
                 "MAC_IPv6_GRE_IPv6-TUNNEL_UDP_PKT":         ["TUNNEL_GRENAT", "INNER_L4_UDP"],
                 "MAC_IPv6_GRE_IPv6-TUNNEL_TCP_PKT":         ["TUNNEL_GRENAT", "INNER_L4_TCP"],
-                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_UDP_PKT":    ["TUNNEL_GRENAT", "INNER_L4_UDP", "PKT_RX_VLAN"],
-                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_TCP_PKT":    ["TUNNEL_GRENAT", "INNER_L4_TCP", "PKT_RX_VLAN"]
+                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_UDP_PKT":    ["TUNNEL_GRENAT", "INNER_L4_UDP", "RTE_MBUF_F_RX_VLAN"],
+                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_TCP_PKT":    ["TUNNEL_GRENAT", "INNER_L4_TCP", "RTE_MBUF_F_RX_VLAN"]
             }
 
             pkt_types_ipv6_ipv6_SCTP = {
                 "MAC_IPv6_GRE_IPv6-TUNNEL_SCTP_PKT":        ["TUNNEL_GRENAT", "INNER_L4_SCTP"],
-                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_SCTP_PKT":   ["TUNNEL_GRENAT", "INNER_L4_SCTP", "PKT_RX_VLAN"]
+                "MAC_VLAN_IPv6_GRE_IPv6-TUNNEL_SCTP_PKT":   ["TUNNEL_GRENAT", "INNER_L4_SCTP", "RTE_MBUF_F_RX_VLAN"]
             }
 
         # Start testpmd and enable rxonly forwarding mode
@@ -379,7 +379,7 @@ class TestIpgre(TestCase):
         self.dut.send_expect("start", "testpmd>")
 
         # Send packet with wrong outer IP checksum and check forwarded packet IP checksum is correct
-        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["PKT_TX_IP_CKSUM"]}
+        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["RTE_MBUF_F_TX_IP_CKSUM"]}
         config_layers = {'ether': {'src': self.outer_mac_src,
                                    'dst': self.outer_mac_dst},
                          'ipv4': {'proto': 'gre',
@@ -400,7 +400,7 @@ class TestIpgre(TestCase):
         self.compare_checksum(pkt)
 
         # Send packet with wrong inner IP checksum and check forwarded packet IP checksum is correct
-        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["PKT_TX_IP_CKSUM"]}
+        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["RTE_MBUF_F_TX_IP_CKSUM"]}
         config_layers = {'ether': {'src': self.outer_mac_src,
                                    'dst': self.outer_mac_dst},
                          'ipv4': {'proto': 'gre',
@@ -421,7 +421,7 @@ class TestIpgre(TestCase):
         self.compare_checksum(pkt)
 
         # Send packet with wrong inner TCP checksum and check forwarded packet TCP checksum is correct
-        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["PKT_TX_TCP_CKSUM"]}
+        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_TCP_PKT": ["RTE_MBUF_F_TX_TCP_CKSUM"]}
         config_layers = {'ether': {'src': self.outer_mac_src,
                                    'dst': self.outer_mac_dst},
                          'ipv4': {'proto': 'gre',
@@ -444,7 +444,7 @@ class TestIpgre(TestCase):
         self.compare_checksum(pkt)
 
         # Send packet with wrong inner UDP checksum and check forwarded packet UDP checksum is correct
-        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_UDP_PKT": ["PKT_TX_UDP_CKSUM"]}
+        pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_UDP_PKT": ["RTE_MBUF_F_TX_UDP_CKSUM"]}
         config_layers = {'ether': {'src': self.outer_mac_src,
                                    'dst': self.outer_mac_dst},
                          'ipv4': {'proto': 'gre',
@@ -465,7 +465,7 @@ class TestIpgre(TestCase):
         self.compare_checksum(pkt)
         if self.nic != "cavium_a063":
             # Send packet with wrong inner SCTP checksum and check forwarded packet SCTP checksum is correct
-            pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_SCTP_PKT": ["PKT_TX_SCTP_CKSUM"]}
+            pkt_types = { "MAC_IP_GRE_IPv4-TUNNEL_SCTP_PKT": ["RTE_MBUF_F_TX_SCTP_CKSUM"]}
             config_layers = {'ether': {'src': self.outer_mac_src,
                                        'dst': self.outer_mac_dst},
                              'ipv4': {'proto': 'gre',
diff --git a/tests/TestSuite_rxtx_offload.py b/tests/TestSuite_rxtx_offload.py
index a9340269..8a4c6519 100644
--- a/tests/TestSuite_rxtx_offload.py
+++ b/tests/TestSuite_rxtx_offload.py
@@ -265,9 +265,9 @@ class TestRxTx_Offload(TestCase):
         m = scanner.search(outstring)
         queue_id = m.group(1)
         if int(queue_id) in queue:
-            self.verify("PKT_RX_VLAN_STRIPPED" in outstring, "Fail to configure offload by queue.")
+            self.verify("RTE_MBUF_F_RX_VLAN_STRIPPED" in outstring, "Fail to configure offload by queue.")
         else:
-            self.verify("PKT_RX_VLAN_STRIPPED" not in outstring, "Fail to configure offload by queue.")
+            self.verify("RTE_MBUF_F_RX_VLAN_STRIPPED" not in outstring, "Fail to configure offload by queue.")
         self.dut.send_expect("stop", "testpmd>")
 
     def checksum_valid_flags(self, packet, direction, flags):
@@ -287,28 +287,28 @@ class TestRxTx_Offload(TestCase):
                 line = line.strip()
                 if len(line) != 0 and line.startswith("rx") and ("flags" in line):
                     if ("ipv4" in flags):
-                        self.verify("PKT_RX_IP_CKSUM_BAD" in line, "ipv4 checksum flag is wrong!")
+                        self.verify("RTE_MBUF_F_RX_IP_CKSUM_BAD" in line, "ipv4 checksum flag is wrong!")
                     else:
-                        self.verify("PKT_RX_IP_CKSUM_GOOD" in line, "ipv4 checksum flag is wrong!")
+                        self.verify("RTE_MBUF_F_RX_IP_CKSUM_GOOD" in line, "ipv4 checksum flag is wrong!")
                     if ("udp" in flags) or ("tcp" in flags):
-                        self.verify("PKT_RX_L4_CKSUM_BAD" or "PKT_RX_L4_CKSUM_UNKNOWN" in line, "L4 checksum flag is wrong!")
+                        self.verify("RTE_MBUF_F_RX_L4_CKSUM_BAD" or "RTE_MBUF_F_RX_L4_CKSUM_UNKNOWN" in line, "L4 checksum flag is wrong!")
                     else:
-                        self.verify(("PKT_RX_L4_CKSUM_GOOD" in line) or ("PKT_RX_L4_CKSUM_UNKNOWN" in line), "L4 checksum flag is wrong!")
+                        self.verify(("RTE_MBUF_F_RX_L4_CKSUM_GOOD" in line) or ("RTE_MBUF_F_RX_L4_CKSUM_UNKNOWN" in line), "L4 checksum flag is wrong!")
         # collect the tx checksum result
         if (direction == "tx"):
             for line in lines:
                 line = line.strip()
                 if len(line) != 0 and line.startswith("tx") and ("flags" in line):
                     if ("ipv4" in flags):
-                        self.verify("PKT_TX_IP_CKSUM" in line, "There is no ipv4 tx checksum flag!")
+                        self.verify("RTE_MBUF_F_TX_IP_CKSUM" in line, "There is no ipv4 tx checksum flag!")
                     if ("udp" in flags):
-                        self.verify("PKT_TX_UDP_CKSUM" in line, "There is no udp tx checksum flag!")
+                        self.verify("RTE_MBUF_F_TX_UDP_CKSUM" in line, "There is no udp tx checksum flag!")
                     if ("tcp") in flags:
-                        self.verify("PKT_TX_TCP_CKSUM" in line, "There is no tcp tx checksum flag!")
+                        self.verify("RTE_MBUF_F_TX_TCP_CKSUM" in line, "There is no tcp tx checksum flag!")
                     if ("sctp") in flags:
-                        self.verify("PKT_TX_SCTP_CKSUM" in line, "There is no sctp tx checksum flag!")
+                        self.verify("RTE_MBUF_F_TX_SCTP_CKSUM" in line, "There is no sctp tx checksum flag!")
                     if (flags == []):
-                        self.verify(("PKT_TX_L4_NO_CKSUM" in line) and ("PKT_TX_IP_CKSUM" not in line), "The tx checksum flag is wrong!")
+                        self.verify(("RTE_MBUF_F_TX_L4_NO_CKSUM" in line) and ("RTE_MBUF_F_TX_IP_CKSUM" not in line), "The tx checksum flag is wrong!")
         self.dut.send_expect("stop", "testpmd>")
 
     def verify_result(self, packet, expect_rxpkts, expect_queue):
diff --git a/tests/TestSuite_vf_vlan.py b/tests/TestSuite_vf_vlan.py
index 28650143..acd97aba 100644
--- a/tests/TestSuite_vf_vlan.py
+++ b/tests/TestSuite_vf_vlan.py
@@ -432,7 +432,7 @@ class TestVfVlan(TestCase):
             vlan_hex = hex(rx_vlan)
             self.verify("VLAN tci=%s" %
                         vlan_hex in out, "Failed to strip vlan packet!!!")
-            self.verify("PKT_RX_VLAN_STRIPPED" in out, "Failed to strip vlan packet!")
+            self.verify("RTE_MBUF_F_RX_VLAN_STRIPPED" in out, "Failed to strip vlan packet!")
 
             self.vm0_testpmd.execute_cmd('vlan set strip off 0')
 
@@ -440,7 +440,7 @@ class TestVfVlan(TestCase):
             self.verify(
                 "received 1 packets" in out, "Not received vlan packet as expected!!!")
             self.verify(
-                "PKT_RX_VLAN_STRIPPED" not in out, "Failed to disable strip vlan!!!")
+                "RTE_MBUF_F_RX_VLAN_STRIPPED" not in out, "Failed to disable strip vlan!!!")
 
         self.vm0_testpmd.quit()
 
diff --git a/tests/TestSuite_vlan_ethertype_config.py b/tests/TestSuite_vlan_ethertype_config.py
index 514bdd1f..e76115ee 100644
--- a/tests/TestSuite_vlan_ethertype_config.py
+++ b/tests/TestSuite_vlan_ethertype_config.py
@@ -182,7 +182,7 @@ class TestVlanEthertypeConfig(TestCase):
                 self.vlan_send_packet(rx_vlan, tpid)
                 out = self.dut.get_session_output()
                 self.verify(
-                    "PKT_RX_VLAN" in out, "Vlan recognized error:" + str(out))
+                    "RTE_MBUF_F_RX_VLAN" in out, "Vlan recognized error:" + str(out))
 
     def test_vlan_filter_on_off(self):
         """
diff --git a/tests/smoke_base.py b/tests/smoke_base.py
index 0d7046b0..80854113 100644
--- a/tests/smoke_base.py
+++ b/tests/smoke_base.py
@@ -86,7 +86,7 @@ class SmokeTest(object):
         queues = queue_pattern.findall(out)
         # get dpdk statistical information
         stats = self.test_case.pmd_out.get_pmd_stats(self.test_case.smoke_dut_ports[0])
-        if 'PKT_RX_RSS_HASH' in out:
+        if 'RTE_MBUF_F_RX_RSS_HASH' in out:
             hash_flag = True
 
         if rss:

diff --git a/tests/TestSuite_checksum_offload.py b/tests/TestSuite_checksum_offload.py
index eee09105..53520543 100644
--- a/tests/TestSuite_checksum_offload.py
+++ b/tests/TestSuite_checksum_offload.py
@@ -187,25 +187,25 @@ class TestChecksumOffload(TestCase):
                 if len(line) != 0 and line.startswith("rx"):
                     # IPv6 don't be checksum, so always show "GOOD"
                     if packet_type.startswith("IPv6"):
-                        if "PKT_RX_L4_CKSUM" not in line:
+                        if "RTE_MBUF_F_RX_L4_CKSUM" not in line:
                             self.verify(0, "There is no checksum flags appeared!")
                         else:
                             if (flag == 1):
-                                self.verify("PKT_RX_L4_CKSUM_GOOD" in line, "Packet Rx L4 checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_L4_CKSUM_GOOD" in line, "Packet Rx L4 checksum valid-flags error!")
                             elif (flag == 0):
-                                self.verify("PKT_RX_L4_CKSUM_BAD" in line or "PKT_RX_L4_CKSUM_UNKNOWN" in line, "Packet Rx L4 checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_L4_CKSUM_BAD" in line or "RTE_MBUF_F_RX_L4_CKSUM_UNKNOWN" in line, "Packet Rx L4 checksum valid-flags error!")
                     else:
-                        if "PKT_RX_L4_CKSUM" not in line:
+                        if "RTE_MBUF_F_RX_L4_CKSUM" not in line:
                             self.verify(0, "There is no L4 checksum flags appeared!")
-                        elif "PKT_RX_IP_CKSUM" not in line:
+                        elif "RTE_MBUF_F_RX_IP_CKSUM" not in line:
                             self.verify(0, "There is no IP checksum flags appeared!")
                         else:
                             if (flag == 1):
-                                self.verify("PKT_RX_L4_CKSUM_GOOD" in line, "Packet Rx L4 checksum valid-flags error!")
-                                self.verify("PKT_RX_IP_CKSUM_GOOD" in line, "Packet Rx IP checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_L4_CKSUM_GOOD" in line, "Packet Rx L4 checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_IP_CKSUM_GOOD" in line, "Packet Rx IP checksum valid-flags error!")
                             elif (flag == 0):
-                                self.verify("PKT_RX_L4_CKSUM_BAD" in line or "PKT_RX_L4_CKSUM_UNKNOWN" in line, "Packet Rx L4 checksum valid-flags error!")
-                                self.verify("PKT_RX_IP_CKSUM_BAD" in line, "Packet Rx IP checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_L4_CKSUM_BAD" in line or "RTE_MBUF_F_RX_L4_CKSUM_UNKNOWN" in line, "Packet Rx L4 checksum valid-flags error!")
+                                self.verify("RTE_MBUF_F_RX_IP_CKSUM_BAD" in line, "Packet Rx IP checksum valid-flags error!")
 
         self.dut.send_expect("stop", "testpmd>")
 
@@ -270,10 +270,10 @@ class TestChecksumOffload(TestCase):
         return self.tester.scapy_execute()
 
     def get_pkt_rx_l4_cksum(self, testpmd_output: str) -> bool:
-        return self.checksum_flags_are_good("PKT_RX_L4_CKSUM_", testpmd_output)
+        return self.checksum_flags_are_good("RTE_MBUF_F_RX_L4_CKSUM_", testpmd_output)
 
     def get_pkt_rx_ip_cksum(self, testpmd_output: str) -> bool:
-        return self.checksum_flags_are_good("PKT_RX_IP_CKSUM_", testpmd_output)
+        return self.checksum_flags_are_good("RTE_MBUF_F_RX_IP_CKSUM_", testpmd_output)
 
     def send_pkt_expect_good_bad_from_flag(self, pkt_str: str, flag: str, test_name: str, should_pass: bool = True):
         self.pmdout.get_output(timeout=1)  # Remove any old output
@@ -692,7 +692,7 @@ class TestChecksumOffload(TestCase):
             for chksum in "", "chksum=0xf":
                 vf = self.send_pkt_expect_good_bad_from_flag_catch_failure(
                     f"eth/IP({chksum})/{l4}()/('X'*50)",
-                    "PKT_RX_IP_CKSUM_", f"{l4}",
+                    "RTE_MBUF_F_RX_IP_CKSUM_", f"{l4}",
                     should_pass=(chksum == ""))
                 if vf is not None:
                     verification_errors.append(vf)
@@ -766,7 +766,7 @@ class TestChecksumOffload(TestCase):
                 for chksum in "", "chksum=0xf":
                     vf = self.send_pkt_expect_good_bad_from_flag_catch_failure(
                         f"eth/{l3}()/{l4}({chksum})/('X'*48)",
-                        "PKT_RX_L4_CKSUM_", f"{l3}/{l4}",
+                        "RTE_MBUF_F_RX_L4_CKSUM_", f"{l3}/{l4}",
                         should_pass=(chksum == ""))
                     if vf is not None:
                         verification_errors.append(vf)
@@ -777,10 +777,10 @@ class TestChecksumOffload(TestCase):
             for l4 in l4_protos:
                 for outer_arg in "", "chksum=0xf":
                     for inner_arg in "", "chksum=0xf":
-                        for flag in "PKT_RX_L4_CKSUM_", "PKT_RX_OUTER_L4_CKSUM_":
-                            if flag == "PKT_RX_L4_CKSUM_":
+                        for flag in "RTE_MBUF_F_RX_L4_CKSUM_", "RTE_MBUF_F_RX_OUTER_L4_CKSUM_":
+                            if flag == "RTE_MBUF_F_RX_L4_CKSUM_":
                                 should_pass = inner_arg == ""
-                            else:  # flag == PKT_RX_OUTER_L4_CKSUM_
+                            else:  # flag == RTE_MBUF_F_RX_OUTER_L4_CKSUM_
                                 # fortville not support outer checksum
                                 if 'fortville' in self.nic:
                                     continue
@@ -801,7 +801,7 @@ class TestChecksumOffload(TestCase):
                     should_pass: bool = inner_arg == ""
                     vf = self.send_pkt_expect_good_bad_from_flag_catch_failure(
                         f"eth/{l3}()/GRE()/{l3}()/{l4}({inner_arg})/('X'*48)",
-                        "PKT_RX_L4_CKSUM_", f"{l3}/GRE/{l3}/{l4}",
+                        "RTE_MBUF_F_RX_L4_CKSUM_", f"{l3}/GRE/{l3}/{l4}",
                         should_pass=should_pass)
 
                     if vf is not None:
@@ -820,8 +820,8 @@ class TestChecksumOffload(TestCase):
         #             for l4 in l4_protos:
         #                 for outer_arg in "", "chksum=0xf":
         #                     for inner_arg in "", "chksum=0xf":
         #                         for flag in "PKT_RX_L4_CKSUM_", "PKT_RX_OUTER_L4_CKSUM_":
         #                             should_pass: bool = inner_arg == "" if flag == "PKT_RX_L4_CKSUM_" else outer_arg == ""
         #                             vf = self.send_pkt_expect_good_bad_from_flag_catch_failure(
         #                                 f"eth/{l3_outer}()/{l4_outer}({outer_arg})/GENEVE()/eth/{l3_inner}()/"
         #                                 f"{l4}({inner_arg})/('X'*50)",
@@ -820,8 +820,8 @@ class TestChecksumOffload(TestCase):
         #                 for outer_arg in "", "chksum=0xf":
         #                     for inner_arg in "", "chksum=0xf":
-        #                         for flag in "PKT_RX_L4_CKSUM_", "PKT_RX_OUTER_L4_CKSUM_":
-        #                             should_pass: bool = inner_arg == "" if flag == "PKT_RX_L4_CKSUM_" else outer_arg == ""
+        #                         for flag in "RTE_MBUF_F_RX_L4_CKSUM_", "RTE_MBUF_F_RX_OUTER_L4_CKSUM_":
+        #                             should_pass: bool = inner_arg == "" if flag == "RTE_MBUF_F_RX_L4_CKSUM_" else outer_arg == ""
         #                             vf = self.send_pkt_expect_good_bad_from_flag_catch_failure(
         #                                 f"eth/{l3_outer}()/{l4_outer}({outer_arg})/GENEVE()/eth/{l3_inner}()/"